@@ -25,7 +25,12 @@ MODULES = (pet,)
 # Functions: Public
 # ======================================================================================================================
 def register_blueprints(api: Api) -> None:
-    """Initialize application with all modules"""
+    """
+    Initialize application with all modules
+
+    Args:
+        api: An initialized Api or Flask app ready to register blueprints.
+    """
 
     for module in MODULES:
         api.register_blueprint(module.BLP)  # type: ignore
